# oneNeuron_pypi
## How to use this packages
```python
from oneNeuron.perceptron import Perceptron

##get x and y values than use below commands
model = Perceptron(eta=eta, epochs=epochs)
model.fit(X, y)
```